==> tool-sql-2.6.0-pre3-sources.jar: io/ciera/tool/sql/ooaofooa/domain/StructureMember.java <==
package io.ciera.tool.sql.ooaofooa.domain;


import io.ciera.runtime.summit.classes.IModelInstance;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.Sql;
import io.ciera.tool.sql.ooaofooa.domain.DataType;
import io.ciera.tool.sql.ooaofooa.domain.Dimensions;
import io.ciera.tool.sql.ooaofooa.domain.DimensionsSet;
import io.ciera.tool.sql.ooaofooa.domain.StructureMember;
import io.ciera.tool.sql.ooaofooa.domain.StructuredDataType;
import io.ciera.tool.sql.ooaofooa.value.MemberValueReference;
import io.ciera.tool.sql.ooaofooa.value.MemberValueReferenceSet;


public interface StructureMember extends IModelInstance<StructureMember,Sql> {

    // attributes
    public void setMember_ID( UniqueId m_Member_ID ) throws XtumlException;
    public UniqueId getMember_ID() throws XtumlException;
    public String getName() throws XtumlException;
    public void setName( String m_Name ) throws XtumlException;
    public void setDescrip( String m_Descrip ) throws XtumlException;
    public String getDescrip() throws XtumlException;
    public UniqueId getParent_DT_DT_ID() throws XtumlException;
    public void setParent_DT_DT_ID( UniqueId ref_Parent_DT_DT_ID ) throws XtumlException;
    public UniqueId getDT_ID() throws XtumlException;
    public void setDT_ID( UniqueId ref_DT_ID ) throws XtumlException;
    public UniqueId getPrevious_Member_ID() throws XtumlException;
    public void setPrevious_Member_ID( UniqueId ref_Previous_Member_ID ) throws XtumlException;
    public String getDimensions() throws XtumlException;
    public void setDimensions( String m_Dimensions ) throws XtumlException;


    // operations


    // selections
    default public void setR44_has_parent_StructuredDataType( StructuredDataType inst ) {}
    public StructuredDataType R44_has_parent_StructuredDataType() throws XtumlException;
    default public void setR45_is_defined_by_DataType( DataType inst ) {}
    public DataType R45_is_defined_by_DataType() throws XtumlException;
    default public void setR46_precedes_StructureMember( StructureMember inst ) {}
    public StructureMember R46_precedes_StructureMember() throws XtumlException;
    default public void setR46_succeeds_StructureMember( StructureMember inst ) {}
    public StructureMember R46_succeeds_StructureMember() throws XtumlException;
    default public void addR53_may_have_Dimensions( Dimensions inst ) {}
    default public void removeR53_may_have_Dimensions( Dimensions inst ) {}
    public DimensionsSet R53_may_have_Dimensions() throws XtumlException;
    default public void addR836_MemberValueReference( MemberValueReference inst ) {}
    default public void removeR836_MemberValueReference( MemberValueReference inst ) {}
    public MemberValueReferenceSet R836_MemberValueReference() throws XtumlException;


}

==> tool-sql-2.7.0-sources.jar: io/ciera/tool/sql/ooaofooa/domain/StructureMember.java <==
package io.ciera.tool.sql.ooaofooa.domain;


import io.ciera.runtime.summit.classes.IModelInstance;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.Sql;
import io.ciera.tool.sql.architecture.classes.Attribute;
import io.ciera.tool.sql.ooaofooa.domain.DataType;
import io.ciera.tool.sql.ooaofooa.domain.Dimensions;
import io.ciera.tool.sql.ooaofooa.domain.DimensionsSet;
import io.ciera.tool.sql.ooaofooa.domain.StructureMember;
import io.ciera.tool.sql.ooaofooa.domain.StructuredDataType;
import io.ciera.tool.sql.ooaofooa.value.MemberValueReference;
import io.ciera.tool.sql.ooaofooa.value.MemberValueReferenceSet;


public interface StructureMember extends IModelInstance<StructureMember,Sql> {

    // attributes
    public UniqueId getMember_ID() throws XtumlException;
    public void setMember_ID( UniqueId m_Member_ID ) throws XtumlException;
    public void setName( String m_Name ) throws XtumlException;
    public String getName() throws XtumlException;
    public void setDescrip( String m_Descrip ) throws XtumlException;
    public String getDescrip() throws XtumlException;
    public void setParent_DT_DT_ID( UniqueId ref_Parent_DT_DT_ID ) throws XtumlException;
    public UniqueId getParent_DT_DT_ID() throws XtumlException;
    public void setDT_ID( UniqueId ref_DT_ID ) throws XtumlException;
    public UniqueId getDT_ID() throws XtumlException;
    public UniqueId getPrevious_Member_ID() throws XtumlException;
    public void setPrevious_Member_ID( UniqueId ref_Previous_Member_ID ) throws XtumlException;
    public String getDimensions() throws XtumlException;
    public void setDimensions( String m_Dimensions ) throws XtumlException;


    // operations


    // selections
    default public void setR44_has_parent_StructuredDataType( StructuredDataType inst ) {}
    public StructuredDataType R44_has_parent_StructuredDataType() throws XtumlException;
    default public void setR45_is_defined_by_DataType( DataType inst ) {}
    public DataType R45_is_defined_by_DataType() throws XtumlException;
    default public void setR46_precedes_StructureMember( StructureMember inst ) {}
    public StructureMember R46_precedes_StructureMember() throws XtumlException;
    default public void setR46_succeeds_StructureMember( StructureMember inst ) {}
    public StructureMember R46_succeeds_StructureMember() throws XtumlException;
    default public void setR4760_Attribute( Attribute inst ) {}
    public Attribute R4760_Attribute() throws XtumlException;
    default public void addR53_may_have_Dimensions( Dimensions inst ) {}
    default public void removeR53_may_have_Dimensions( Dimensions inst ) {}
    public DimensionsSet R53_may_have_Dimensions() throws XtumlException;
    default public void addR836_MemberValueReference( MemberValueReference inst ) {}
    default public void removeR836_MemberValueReference( MemberValueReference inst ) {}
    public MemberValueReferenceSet R836_MemberValueReference() throws XtumlException;


}
